@@ -60,19 +60,27 @@ class ImageClient(object):
                 response = requests.get(image_url, headers=headers, auth=auth)
                 if response.status_code <= 204:
                     data = response.content
-                    with Image.open(BytesIO(data)) as img:
+                    with Image.open(BytesIO(data)).convert('RGB') as img:
+
+                        # convert to webp
+                        with BytesIO() as f:
+                            img.save(f, format='webp')
+                            f.seek(0)
+                            img = Image.open(f)
+                            file_name = ''.join(os.path.basename(image_url).split('.')[0]) + '.webp'
+
                         width, height = img.size
                         size = len(img.fp.read())
-                        return width, height, size, data
+                        return file_name, width, height, size, data
             except Exception as e:
                 print(e)
         return None, None, None, None
 
     def upload_image_to_storage(self, id, bucket_name, image_url, auth=None):
-        width, heigth, byte_size, image = self.get_image(image_url, auth)
+        file_name, width, heigth, byte_size, image = self.get_image(image_url, auth)
         if image:
             bucket = self.storage_client.get_bucket(f'{bucket_name}-{self.project_id}')
-            blob = bucket.blob(f"{id}/{os.path.basename(image_url)}")
+            blob = bucket.blob(f"{id}/{file_name}")
             new_image_url = self.storage_client.upload_from_string(blob, image)
             return width, heigth, byte_size, new_image_url
         else:
